ycleptic
========

**Ycleptic** (ee-KLEP-tic) is a Python tool for facilitating the definition of
YAML-format input files.  It allows for specification of default values and 
value choices.  It allows for fully nested dictionary/list structures for
detailed input file organization.

.. note::

   Ycleptic is under active development.

.. note:: 

   Ycleptic is used in the `pestifer <https://pypi.org/project/pestifer/>`_ package.

Contents
--------

.. toctree::
   :maxdepth: 1
   
   about
   installation
   usage
   API <api/API>

